@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Hash;
 {
-  $List::Objects::WithUtils::Role::Hash::VERSION = '0.002002';
+  $List::Objects::WithUtils::Role::Hash::VERSION = '0.002003';
 }
 use strictures 1;
 
@@ -89,6 +89,7 @@ List::Objects::WithUtils::Role::Hash - Hash manipulation methods
 
 =head1 SYNOPSIS
 
+  ## Via List::Objects::WithUtils::Hash ->
   use List::Objects::WithUtils 'hash';
 
   my $hash = hash(foo => 'bar');
@@ -109,6 +110,10 @@ List::Objects::WithUtils::Role::Hash - Hash manipulation methods
     my ($key, $val) = @$pair;
   }
 
+  ## As a Role ->
+  use Role::Tiny::With;
+  with 'List::Objects::WithUtils::Role::Hash';
+
 =head1 DESCRIPTION
 
 A L<Role::Tiny> role defining methods for creating and manipulating HASH-type
